<?php
/*
Author: Arefly
URL: http://www.arefly.com/

Thanks for using Arefly V1!
*/

define("AREFLY_V1_VERSION", "1.0");
define("AREFLY_V1_URL", "http://www.arefly.com/arefly-v1/");

/*
1. lib/clean.php
  - head cleanup
	- post and images related cleaning
*/
require_once('lib/clean.php'); // do all the cleaning and enqueue here

/*
2. lib/enqueue-style.php
	- enqueue Foundation and Reverie CSS
*/
require_once('lib/enqueue-style.php');

/*
3. lib/foundation.php
	- add pagination
*/
require_once('lib/foundation.php'); // load Foundation specific functions like top-bar
/*
4. lib/nav.php
	- custom walker for top-bar and related
*/
require_once('lib/nav.php'); // filter default wordpress menu classes and clean wp_nav_menu markup

/*
5. lib/seo.php
	- add header seo pack
*/
require_once('lib/seo.php');

/*
6. lib/options.php
	- add theme option page
*/
require_once('lib/options.php');

/**********************
Add theme supports
 **********************/
if( ! function_exists( 'arefly_v1_theme_support')){
	function arefly_v1_theme_support() {
		// Add language supports.
		load_theme_textdomain('arefly-v1', get_template_directory() . '/lang');

		// Add post thumbnail supports. http://codex.wordpress.org/Post_Thumbnails
		add_theme_support('post-thumbnails');
		// set_post_thumbnail_size(150, 150, false);
		add_image_size('fd-lrg', 1024, 99999);
		add_image_size('fd-med', 768, 99999);
		add_image_size('fd-sm', 320, 9999);

		// rss thingy
		add_theme_support('automatic-feed-links');

		// Add post formats support. http://codex.wordpress.org/Post_Formats
		add_theme_support('post-formats', array('aside', 'gallery', 'link', 'image', 'quote', 'status', 'video', 'audio', 'chat'));

		// Add menu support. http://codex.wordpress.org/Function_Reference/register_nav_menus
		add_theme_support('menus');
		register_nav_menus(array(
			'primary' => __('Top Navigation', 'arefly-v1'),
			'utility' => __('Bottom Navigation', 'arefly-v1')
		));

		// Add custom background support
		add_theme_support( 'custom-background',
			array(
				'default-image' => '',  // background image default
				'default-color' => '', // background color default (dont add the #)
				'wp-head-callback' => '_custom_background_cb',
				'admin-head-callback' => '',
				'admin-preview-callback' => ''
			)
		);
	}
}
add_action('after_setup_theme', 'arefly_v1_theme_support'); /* end Reverie theme support */

// create widget areas: sidebar, footer
$sidebars = array('Sidebar');
foreach ($sidebars as $sidebar) {
	register_sidebar(array(
		'name'=> $sidebar,
		'id' => 'Sidebar',
		'before_widget' => '<article id="%1$s" class="panel widget %2$s">',
		'after_widget' => '</article>',
		'before_title' => '<h4>',
		'after_title' => '</h4>'
	));
}
$sidebars = array('Footer');
foreach ($sidebars as $sidebar) {
	register_sidebar(array(
		'name'=> $sidebar,
		'id' => 'Footer',
		'before_widget' => '<div class="large-3 columns"><article id="%1$s" class="panel widget %2$s">',
		'after_widget' => '</article></div>',
		'before_title' => '<h4>',
		'after_title' => '</h4>'
	));
}

// return entry meta information for posts, used by multiple loops, you can override this function by defining them first in your child theme's functions.php file
if(!function_exists( 'arefly_v1_entry_meta')){
	function arefly_v1_entry_meta() {
		echo '<span class="byline author">'. __('Written by', 'arefly-v1') .' <a href="'. get_author_posts_url(get_the_author_meta('ID')) .'" rel="author" class="fn">'. get_the_author() .', </a></span>';
		echo '<time class="updated" datetime="'. get_the_time('c') .'" pubdate>'. get_the_time('F jS, Y') .'</time>';
	}
};

if ( ! isset( $content_width ) ) $content_width = 760;

/************************* START YOUR OWN FUNCTION HERE *************************/



?>